@@ -2,8 +2,8 @@ import logging
 
 # set up logging to file - see previous section for more details
 logging.basicConfig(level=logging.DEBUG,
-                    format='%(asctime)s %(name)-12s %(levelname)-8s %(message)s',
-                    datefmt='%m-%d %H:%M')
+                    format='%(asctime)s %(levelname)-5s %(message)s',
+                    datefmt='%Y-%m-%d %H:%M:%S')
 
 # define a Handler which writes INFO messages or higher to the sys.stderr
 console = logging.StreamHandler()
